"{ Package: 'stx:libbasic' }"

Object subclass:#AbstractObjectCoder
	instanceVariableNames:''
	classVariableNames:''
	poolDictionaries:''
	category:'System-Storage'
!

!AbstractObjectCoder class methodsFor:'documentation'!

documentation
"
    This class is defines #encodeXXX:with: messages for various kinds of objects.
    Any of these messsages is mapped to #encodeObject:with:.

    When a class redefines #encodeOn:with:, an method has to be defined here, too.

    Subclasses have to define at least #encodeObject:with:

    [author:]
        Stefan Vogel (stefan@zwerg)

    [see also:]
        Object>>encodeOn:with:
"
! !

!AbstractObjectCoder methodsFor:'encoding-smalltalk-types'!

encodeAbsoluteTime:anAbsoluteTime with:aParameter
    "encode an absolute time value"

    self encodeObject:anAbsoluteTime with:aParameter


!

encodeBehavior:aSymbol with:aParameter
    "encode a class"

    self encodeObject:aSymbol with:aParameter
!

encodeBitArray:aBitArray with:aParameter
    "encode a BitArray"

    self encodeSequenceableCollection:aBitArray with:aParameter
!

encodeBoolean:aBoolean with:aParameter
    "encode a Boolean"

    self encodeObject:aBoolean with:aParameter


!

encodeByteArray:aByteArray with:aParameter
    "encode an absolute time value"

    self encodeSequenceableCollection:aByteArray with:aParameter
!

encodeCharacter:aCharacter with:aParameter
    "encode a Character"

    self encodeObject:aCharacter with:aParameter


!

encodeCollection:aCollection with:aParameter
    "encode a Collection"

    self encodeObject:aCollection with:aParameter
!

encodeDictionary:aDictionary with:aParameter
    "encode a Dictionary"

    self encodeCollection:aDictionary with:aParameter
!

encodeFloat:aFloat with:aParameter
    "encode a Float"

    self encodeNumber:aFloat with:aParameter
!

encodeFraction:aFraction with:aParameter
    "encode a Fraction"

    self encodeNumber:aFraction with:aParameter
!

encodeInteger:anInteger with:aParameter
    "encode an Integer"

    self encodeNumber:anInteger with:aParameter
!

encodeNilWith:aParameter
    "encode a nil"

    self encodeObject:nil with:aParameter


!

encodeNumber:aNumber with:aParameter
    "encode an Integer"

    self encodeObject:aNumber with:aParameter
!

encodeSequencableCollection:aCollection with:aParameter
    "encode a SequenceableCollection.
     This is the wrong spelling but kept foe backward compatibility"

    self encodeCollection:aCollection with:aParameter
!

encodeSequenceableCollection:aCollection with:aParameter
    "encode a SequenceableCollection"

    "send the historic (wrong) selector, for backward compatibility with old subclasses"
    self encodeSequencableCollection:aCollection with:aParameter
!

encodeSet:aCollection with:aParameter
    "encode a Set"

    self encodeCollection:aCollection with:aParameter
!

encodeString:aString with:aParameter
    "encode a String"

    self encodeObject:aString with:aParameter


!

encodeSymbol:aSymbol with:aParameter
    "encode a Symbol"

    self encodeObject:aSymbol with:aParameter


! !

!AbstractObjectCoder methodsFor:'subclass responsibility'!

encodeObject:anObject with:aParameter
    "encode an object. Subclasses must implement this method"

    self subclassResponsibility


! !

!AbstractObjectCoder class methodsFor:'documentation'!

version
    ^ '$Header: /cvs/stx/stx/libbasic/Attic/AbstractObjectCoder.st,v 1.4 2002-07-02 12:40:04 stefan Exp $'
! !
